﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using HeuristicLab.MainForm;
using HeuristicLab.Optimization.Views;
using HeuristicLab.Core.Views;

namespace HeuristicLab.HiveEngine.Views {
  [View("Hive Engine View")]
  [Content(typeof(HiveEngine), IsDefaultView = true)]
  public sealed partial class HiveEngineView : EngineView {
    public new HiveEngine Content {
      get { return (HiveEngine)base.Content; }
      set { base.Content = value; }
    }

    public HiveEngineView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.ExecutionTimeOnHiveChanged -= new EventHandler(Content_ExecutionTimeOnHiveChanged);
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ExecutionTimeOnHiveChanged += new EventHandler(Content_ExecutionTimeOnHiveChanged);
    }

    #region Event Handlers (Content)
    private void Content_ExecutionTimeOnHiveChanged(object sender, EventArgs e) {
      if (InvokeRequired) {
        Invoke(new EventHandler(Content_ExecutionTimeOnHiveChanged), sender, e);
      } else {
        executionTimeOnHiveTextBox.Text = Content.ExecutionTimeOnHive.ToString();
      }
    }
    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        resourceIdsTextBox.Text = string.Empty;
        priorityTextBox.Text = string.Empty;
        executionTimeOnHiveTextBox.Text = string.Empty;
      } else {
        resourceIdsTextBox.Text = Content.ResourceIds;
        priorityTextBox.Text = Content.Priority.ToString();
        executionTimeOnHiveTextBox.Text = Content.ExecutionTimeOnHive.ToString();
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      // Enable or disable controls based on whether the content is null or the view is set readonly
      if (Content != null) {
        resourceIdsTextBox.ReadOnly = this.ReadOnly;
        priorityTextBox.ReadOnly = this.ReadOnly;
      } else {
        resourceIdsTextBox.ReadOnly = false;
        priorityTextBox.ReadOnly = false;
      }
    }
    
    #region Event Handlers (child controls)
    private void resourceIdsTextBox_TextChanged(object sender, EventArgs e) {
      Content.ResourceIds = resourceIdsTextBox.Text;
    }
    #endregion

    private void priorityTextBox_TextChanged(object sender, EventArgs e) {
      Content.Priority = int.Parse(priorityTextBox.Text);
    }
  }
}
